# Pre-Installation Notes

## HTMX Navigation

Proxbox still has known UI issues when NetBox HTMX navigation is disabled. For background, see [issue #277](https://github.com/netdevopsbr/netbox-proxbox/issues/277).

Before using the plugin, check your NetBox user preferences at `/user/preferences` and enable HTMX navigation.

![HTMX preference example](https://github.com/user-attachments/assets/f29d13c1-4933-4e25-b97b-81b5f3e76fe7)
